@@ -10,6 +10,8 @@ import aiohttp
 from systembridgeconnector.base import Base
 from systembridgeconnector.const import (
     EVENT_API_KEY,
+    EVENT_APP_ICON,
+    EVENT_APP_NAME,
     EVENT_BASE,
     EVENT_DATA,
     EVENT_DIRECTORIES,
@@ -23,6 +25,8 @@ from systembridgeconnector.const import (
     EVENT_PATH,
     EVENT_SUBTYPE,
     EVENT_TEXT,
+    EVENT_TIMEOUT,
+    EVENT_TITLE,
     EVENT_TYPE,
     EVENT_URL,
     EVENT_VERSION,
@@ -30,6 +34,7 @@ from systembridgeconnector.const import (
     MODEL_MEDIA_DIRECTORIES,
     MODEL_MEDIA_FILE,
     MODEL_MEDIA_FILES,
+    MODEL_RESPONSE,
     SUBTYPE_BAD_API_KEY,
     SUBTYPE_LISTENER_ALREADY_REGISTERED,
     TYPE_APPLICATION_UPDATE,
@@ -45,6 +50,7 @@ from systembridgeconnector.const import (
     TYPE_GET_FILES,
     TYPE_KEYBOARD_KEYPRESS,
     TYPE_KEYBOARD_TEXT,
+    TYPE_NOTIFICATION,
     TYPE_OPEN,
     TYPE_POWER_HIBERNATE,
     TYPE_POWER_LOCK,
@@ -110,7 +116,7 @@ class WebSocketClient(Base):
             aiohttp.ClientConnectionError,
             socket.gaierror,
         ) as error:
-            self._logger.error(
+            self._logger.warning(
                 "Failed to connect to WebSocket: %s - %s",
                 error.__class__.__name__,
                 error,
@@ -298,6 +304,34 @@ class WebSocketClient(Base):
                 )
             )
 
+    async def send_notification(
+        self,
+        message: str,
+        title: str | None = None,
+        app_name: str | None = None,
+        app_icon: str | None = None,
+        timeout: int = 5,
+    ) -> None:
+        """Send notification"""
+        if not self.connected:
+            raise ConnectionClosedException("Connection is closed")
+
+        self._logger.info("Send notification: %s", message)
+        if self._websocket is not None:
+            await self._websocket.send_str(
+                json.dumps(
+                    {
+                        EVENT_EVENT: TYPE_NOTIFICATION,
+                        EVENT_API_KEY: self._api_key,
+                        EVENT_MESSAGE: message,
+                        EVENT_TITLE: title,
+                        EVENT_APP_NAME: app_name,
+                        EVENT_APP_ICON: app_icon,
+                        EVENT_TIMEOUT: timeout,
+                    }
+                )
+            )
+
     async def open_path(
         self,
         path: str,
@@ -437,6 +471,7 @@ class WebSocketClient(Base):
     async def listen(
         self,
         callback: Callable,
+        accept_other_types: bool = False,
     ) -> None:
         """Listen for messages and map to modules"""
 
@@ -452,7 +487,9 @@ class WebSocketClient(Base):
                 message[EVENT_TYPE] == TYPE_DATA_UPDATE
                 and message[EVENT_DATA] is not None
             ):
-                self._logger.debug("New data for: %s", message[EVENT_MODULE])
+                self._logger.debug(
+                    "New data for: %s\n%s", message[EVENT_MODULE], message[EVENT_DATA]
+                )
                 model = MODEL_MAP.get(message[EVENT_MODULE])
                 if model is None:
                     self._logger.warning("Unknown model: %s", message[EVENT_MODULE])
@@ -496,6 +533,15 @@ class WebSocketClient(Base):
                         }
                     ),
                 )
+            else:
+                self._logger.debug("Other message: %s", message[EVENT_TYPE])
+                if accept_other_types:
+                    model = MODEL_MAP.get(EVENT_TYPE, MODEL_MAP[MODEL_RESPONSE])
+                    if model is not None:
+                        await callback(
+                            message[EVENT_TYPE],
+                            model(**message),
+                        )
 
         await self.listen_for_messages(callback=_callback_message)
 
